# LinkedIn Messaging API

[![Python](https://github.com/sumnerevans/linkedin-messaging-api/actions/workflows/python.yaml/badge.svg)](https://github.com/sumnerevans/linkedin-messaging-api/actions/workflows/python.yaml)
[![Matrix Chat](https://img.shields.io/matrix/linkedin-matrix:nevarro.space?server_fqdn=matrix.nevarro.space)](https://matrix.to/#/#linkedin-matrix:nevarro.space?via=nevarro.space&via=sumnerevans.com)

An unofficial API for interacting with LinkedIn Messaging.

Built using [aiohttp](https://docs.aiohttp.org/en/stable/).

## Documentation

See [`examples` directory](./examples).

## Credits

Inspired by [linkedin-api](https://github.com/tomquirk/linkedin-api).

Authentication technique from [@everping](https://github.com/everping) in the
[Linkedin-Authentication-Challenge](https://github.com/everping/Linkedin-Authentication-Challenge)
repo. Used with permission.
